@@ -23,6 +23,8 @@ class MessageProtocolRS232(MessageProtocol):
             try:
                 endpoint = "COM{}".format(i)
                 connection = serial.Serial(port=endpoint, baudrate=baudrate, timeout=TIMEOUT_TO_WAIT_HANDSHAKE_RESPONSE)
+                MAX_UNSIGNED_INT = 4_294_967_295
+                connection.set_buffer_size(rx_size = MAX_UNSIGNED_INT, tx_size = MAX_UNSIGNED_INT)
                 if not connection.isOpen():
                     connection.open()
 
@@ -66,8 +68,9 @@ class MessageProtocolRS232(MessageProtocol):
         # Helper function to recv n bytes or raise ConnectionResetError if EOF is hit
         data = bytearray()
         while len(data) < n:
-            packet = self._connection.read(n - len(data))
+            bytes_to_read = max(1, min(2048, self._connection.in_waiting, n))
+            packet = self._connection.read(bytes_to_read)
             if not packet:
                 raise ConnectionResetError
             data.extend(packet)
-        return data
+        return data
\ No newline at end of file
